@@ -267,9 +267,18 @@ sub add_db_column($@) {
 		$opt{no_quick_search} = \1;
 	}
 	# --
-	
+  
 	$opt{allow_edit} = \0 unless ($editable);
 	$opt{allow_add} = \0 unless ($creatable);
+  
+  # New: flip the allow edit/add flags on if they are not already set to something,
+  # and no_column is not set. This is needed for the case of creatable but not
+  # editable, since the default allow_add is based on the value of allow_edit, which
+  # is intended for the case of it being set by the user
+  unless(jstrue($opt{no_column})) {
+    $opt{allow_edit} //= \1 if ($editable);
+    $opt{allow_add}  //= \1 if ($creatable);
+  }
 
 	unless ($editable or $creatable) {
 		$opt{rel_combo_field_cnf} = $opt{editor} if($opt{editor});
